@@ -1,6 +1,6 @@
 import click
 
-from .logic import clone, submit
+from .logic import run_clone, run_submit
 
 @click.group()
 def cli():
@@ -9,9 +9,9 @@ def cli():
 @cli.command()
 @click.argument('api_url', required=True)
 def clone(api_url):
-    clone(api_url)
+    run_clone(api_url)
 
 @cli.command()
 @click.argument('flag', required=True)
 def submit(flag):
-    submit(flag)
\ No newline at end of file
+    run_submit(flag)
\ No newline at end of file
