@@ -7,10 +7,12 @@ from .file import File
 class Challenge(APIBaseObject):
     def __init__(self, object_id, ctf, data=None):
         self.id = object_id
+        self.unlocked = False
         self.ctf = ctf
         super(Challenge, self).__init__(ctf, data=data)
-        self.convert_json_to_hints()
-        self.convert_json_to_files()
+        if self.unlocked:
+            self.convert_json_to_hints()
+            self.convert_json_to_files()
 
     def get_api_path(self):
         return f"challenges/{self.id}/"
